AlarmSubscribe class

报警消息订阅

Inheritance

Constructors

AlarmSubscribe({required List<AlarmSubscribeBody?> snlist, required List<TokenListElement?> tklist, required String userId, String? voclist = ""})

Properties

hashCode int
The hash code for this object.
no setterinherited
msg String
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snlist List<AlarmSubscribeBody?>
getter/setter pair
tklist List<TokenListElement?>
getter/setter pair
userId String
getter/setter pair
voclist String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited