AlarmUnsubscribe class

取消报警订阅状态

Inheritance

Constructors

AlarmUnsubscribe({required List<AlarmSubscribebaseBody?> snlist, required List<TokenListbaseElement?>? tklist, String? all = "0", int? ut = 0})
AlarmUnsubscribe.byUserId({required List<AlarmSubscribebaseBody?> snlist, required String? userId, String? all = "3", int? ut = 0})

Properties

all String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
msg String
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snlist List<AlarmSubscribebaseBody?>
设备序列号集合
getter/setter pair
tklist List<TokenListbaseElement?>?
phone token集合
getter/setter pair
userId String?
getter/setter pair
ut int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited