JFApi class
Constructors
- JFApi()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- xcAccount → AccountAPI
-
final
- xcAlarmMessage → AlarmMessageAPI
-
final
- xcAppInfo → AppInfoAPI
-
final
- xcCloudService → CloudServiceAPI
-
final
- xcCloudVideoDownloadController → CloudVideoDownloadController
-
final
- xcDevice → DeviceAPI
-
final
- xcDeviceUpgrade → DeviceUpgradeAPI
-
final
- xcDevsCloudAPI → DevicesCloudAPI
-
final
- xcMediaDownload → MediaDownloadAPI
-
final
- xcMediaDownloadController → MediaDownloadController
-
final
- xcMobileSystemInfo → MobileSystemAPI
-
final
- xcMqtt → MqttAPI
-
final
- xcNet → NetAPI
-
final
- xcSDKInit → SDKInitAPI
-
final
- xcUtil → UtilAPI
-
final
- xcVideoPlay → VideoPlayAPI
-
final