DeviceUpgradeAPI class
Constructors
Properties
-
deviceUpgradeStream
→ Stream<
DeviceUpgradeProgressResponse> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
xcDeviceDownloadFile(
{required String commandBody, required String fileSavePath}) → Future< DownloadFileByAppResponse> - app下载固件
-
xcDeviceUpgradeByFile(
{required String deviceId, required String filePath}) → Future< int> -
设备升级-byfile
deviceId设备序列号filePath给设备升级的固件文件地址 回调码 1306 -
xcDeviceUpgradeBySelf(
{required String deviceId, required String bodyJson}) → Future< int> - 设备自身升级
-
xcDeviceVersionCheck(
{required String deviceId, required DeviceVersionCheck devVerCheck}) → Future< DeviceVersionCheckResponse> -
检查设备是否需要升级,支持多模块检测
deviceId设备序列号 commandId 13400
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → DeviceUpgradeAPI
-
no setter