DeviceVersionCheckResponse class

设备升级检测结果回调

Constructors

DeviceVersionCheckResponse({required int code, String? versionInfo})

Properties

code int
result id
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isLatest DeviceVersion
是不是最新版本
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
versionInfo String?
新版本信息
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited