UpgradeState enum

Inheritance
Available extensions

Values

updateCheck → const UpgradeState

升级检查

downloadCloudFile → const UpgradeState

下载升级文件过程(通过服务器升级),进度0~100

sendFileToDevice → const UpgradeState

发送升级文件给设备 ,进度0~100

sendFileToDeviceComplete → const UpgradeState

发送文件完成

upgrading → const UpgradeState

设备正在升级 进度0~100: 升级过程进度

upgradeComplete → const UpgradeState

设备升级完成

over → const UpgradeState

整个升级步骤完成 进度1: 升级过程结束等待设备重启 进度100: 设备重启成功 小于0: 失败错误返回

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<UpgradeState>
A constant List of the values in this enum, in order of their declaration.