RecordDownloadModel class

Constructors

RecordDownloadModel({int? channel, String? saveFileName, int? saveFileLen, int? streamType, String? beginTime, String? endTime, String? fileName})
RecordDownloadModel.fromJson(Map<String, dynamic> json)

Properties

beginTime String?
getter/setter pair
channel int?
getter/setter pair
deviceId String?
额外添加
getter/setter pair
endTime String?
getter/setter pair
fileName String?
getter/setter pair
handle int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
key String
no setter
progress int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveFileLen int?
getter/setter pair
saveFileName String?
getter/setter pair
state RecordDownloadModelState?
getter/setter pair
streamType int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited