MqttAPI class

Constructors

MqttAPI()

Properties

hashCode int
The hash code for this object.
no setterinherited
mqttStream Stream<MqttResponse>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

initMqtt(String userId, String accessToken, String packetName) Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribe(Map<String, dynamic> subscribeInfo) Future<int>
toString() String
A string representation of this object.
inherited
unInitMqtt() → void
unSubscribe(Map<String, dynamic> subscribeInfo) Future<int>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance MqttAPI
no setter