OriginResponse class

脚本命令: flutter pub run pigeon --input lib/api/pigeon/xcloud_api.dart

Annotations
  • @ConfigurePigeon.new(PigeonOptions(dartOut: 'lib/api/pigeon/pigeon_gen/xcloud_api.g.dart', javaOut: 'android/src/main/java/com/lib/xcloud_flutter/pigeon/XCloudAPIGen.java', javaOptions: JavaOptions(package: 'com.lib.xcloud_flutter.pigeon'), objcHeaderOut: 'ios/Classes/XCloudAPIGen.h', objcSourceOut: 'ios/Classes/XCloudAPIGen.m'))

Constructors

OriginResponse({required int commandId, required int param1, required int? param2, required int? param3, String data = '', List<int?>? byteStream})

Properties

byteStream List<int?>?
SDK -- pData 使用之前判断是否为空
getter/setter pair
commandId int
调用原生接口返回的回调数据 消息id SDK -- what
getter/setter pair
data String
SDK -- str
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
param1 int
判断是否业务成功 SDK -- parma1
getter/setter pair
param2 int?
getter/setter pair
param3 int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited