XCAppInfoAPIHost class abstract

App相关 ####################################################################

Annotations
  • @HostApi.new()

Constructors

XCAppInfoAPIHost()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
xcAppRate(String appId) → void
给app评分
xcAppRateAndroid(String appName) String
Android App评分.可能没有应用市场 如果 返回结果为 '' 代表成功, 否则提示失败

Operators

operator ==(Object other) bool
The equality operator.
inherited