XCloudDeviceCloudServiceApiHost class abstract

关于设备云存储模块相关 ####################################################################

Annotations
  • @HostApi.new()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
xcDevsGetCapAbility(String devsSysInfo, int seq) OriginResponse

Operators

operator ==(Object other) bool
The equality operator.
inherited