XCloudDeviceSerialPortApiHost class abstract

串口相关 ####################################################################

Annotations
  • @HostApi.new()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

closeTransparentSerialPort(int nTransHandleint) OriginResponse
关闭透明串口通道 nTransHandleint 透明串口通道句柄
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openTransparentSerialPort(String deviceID, int serialPortType, int seq) OriginResponse
打开透明串口通道 deviceID 设备序列号 serialPortType 串口类型"RS232"/"RS485" commandID 12107
toString() String
A string representation of this object.
inherited
writeDataToSerialPort(String deviceId, int serialPortType, String data, int dataLength, int seq) OriginResponse
向透明串口写入数据 deviceID 设备序列号 serialPortType 串口类型"RS232"/"RS485" data 需要传的数据 dataLength 数据长度

Operators

operator ==(Object other) bool
The equality operator.
inherited