XCloudInitApiHost class abstract

XCloudInitApiHost SDK初始化 ####################################################################

Annotations
  • @HostApi.new()

Constructors

XCloudInitApiHost()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAuthSignInfo() String
获取时间戳和签名信息
init(String param) OriginResponse
SDK初始化接口 return code:0 (直接返回,无需等待回调)
initBasicInfo(String param) OriginResponse
初始化一些账户系统需要使用的基础信息 { "msg" : "at_basic_info" "useragent" : "", ///< 【可选】用户代理信息,用于记录访问当前服务器的客户标识 "codesize" : "6", ///< 【可选】服务器下发验证码长度 默认"6" "language" : "zh_CN", ///< 【可选】 语言 "region" : "", ///< 【可选】地区 "accesstoken" : "", ///< 【可选】访问令牌信息 【慎用】会覆盖当前账户信息,为了类似于jlink,账户登录不在SDK内部做的客户端使用 "logintype" : "" ///< 【可选】登录类型 通用传"", 第三方传"wx" "fb" "gg" "line"等 【慎用】同上 }
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAppParam(String param) OriginResponse
更新鉴权信息
setServerAddressByUrl(String serverKey, String serverIP) → void
设置服务器默认地址 szServerKey 服务器Key szServerIP 城市数据下发的服务器地址
setServerIPAndPort(String serverKey, String serverIP, int httpsPort, int httpPort) OriginResponse
设置服务器默认地址 szServerKey 服务器Key szServerIP 输入服务器IP或域名,NULL:表示不修改;其它值:修改 nHttpsPort 输入默认服务器HTTPS端口,要求>=0 nHttpPort 输入默认服务器HTTP端口,要求>=0
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited