XCloudMobileSystemInfoAPIHost class abstract
手机系统配置相关 ####################################################################
- Annotations
-
- @HostApi.new()
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
xcLocalePreferredLanguage(
) → String - 获取手机当前系统语言
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited