XCloudNetApiHost class abstract

NetApi wifi、蓝牙相关 ####################################################################

Annotations
  • @HostApi.new()

Constructors

XCloudNetApiHost()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
xcBlueToothConnectDevice(String pid, String mac, int seq) OriginResponse
xcBlueToothIsEnable() OriginResponse
蓝牙是否可用 仅用于iOS androi的请使用 CloudBleApiHost 中的isEnable 系统支持蓝牙 && 蓝牙已经打开
xcBlueToothSearchStart(int seq) OriginResponse
xcBlueToothSearchStop(int seq) OriginResponse
xcBlueToothWriteDataToDevice(String ssid, String password, String mac, int seq) OriginResponse
xcGetPhoneIp(int seq) OriginResponse
获取手机的网络的ip地址
xcWifiGetMac(int seq) OriginResponse
xcWifiGetSSID(int seq) OriginResponse

Operators

operator ==(Object other) bool
The equality operator.
inherited