AudioPlayer class
- Inheritance
-
- Object
- PlatformInterface
- AudioPlayerPlatform
- AudioPlayer
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendTalkData(
int playHandle) → Future< int> -
通知原生开始发送数据
原生SDK会自动发送.这里原生空实现预留一下.
不需要调用这个接口
override
-
setVolume(
int audioHandle, int volume) → Future< int> -
设置对讲音量,0-100 0 表示关闭
override
-
startTalk(
String deviceId, StartTalk talk, int type) → Future< int> -
开启对讲,返回 音频播放 句柄
原生开启之后,会自动采集音频数据发送到SDK
type0 半双工 1 双工override -
stopTalkPlay(
int audioHandle, {int mediaType = 1}) → Future< int> -
停止对讲.释放资源空间
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited