BleDistributeWifiStatus enum
Values
- none → const BleDistributeWifiStatus
-
初始状态
- bleConnecting → const BleDistributeWifiStatus
-
蓝牙正在连接
- bleConnected → const BleDistributeWifiStatus
-
蓝牙连接成功,且设置好回调
- listening → const BleDistributeWifiStatus
-
建立notify监听
- writing → const BleDistributeWifiStatus
-
写入路由配置信息,将WIFI信息发送给设备
- distributing → const BleDistributeWifiStatus
-
设备正在配置.等待设备返回设备信息
- distributeSuccess → const BleDistributeWifiStatus
-
配网成功,返回设备的信息
- error → const BleDistributeWifiStatus
-
发生错误
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BleDistributeWifiStatus> - A constant List of the values in this enum, in order of their declaration.