AddDownloadComPicToTaskList class

下载SD卡存图片裁切图json对象

Constructors

AddDownloadComPicToTaskList({int height = 45, int width = 80, int isGeo = 1, required String picName})

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
getter/setter pair
isGeo int
getter/setter pair
picName String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonString() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited