DownloadRecordThumbnailModel class

下载SD卡存录像段缩略图json对象

Constructors

DownloadRecordThumbnailModel({int channel = 0, required String filePath, required String startTime, required String endTime, String fileType = '*'})

Properties

channel int
通道号
getter/setter pair
endTime String
getter/setter pair
filePath String
文件路径
getter/setter pair
fileType String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
maxPicCount int
最大图片数量
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonString() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited