SDCardAlarmMsgLocal class

不用继承是因为参数msg可以直接用来发消息

Constructors

SDCardAlarmMsgLocal(String? localPath, SearchSDCardAlarmMsg? msg, {List<int?>? imageData})

Properties

hashCode int
The hash code for this object.
no setterinherited
imageData List<int?>?
图片数据信息
getter/setter pair
localPath String?
缩略图存储路径
getter/setter pair
msg SearchSDCardAlarmMsg?
SDK获取图片信息参数
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited