SearchSDCardAlarmMsg class

Constructors

SearchSDCardAlarmMsg(String? beginTime, int? diskNo, String? endTime, String? fileLength, String? fileName, int? serialNo)
SearchSDCardAlarmMsg.fromJson(Map<String, dynamic> map)

Properties

beginTime String?
getter/setter pair
diskNo int?
getter/setter pair
endTime String?
getter/setter pair
fileLength String?
getter/setter pair
fileName String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialNo int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited