WifiConfigState class

Constructors

WifiConfigState({bool gettingWifiInfo = false, String? ssid, WifiScanResult? scanResult, DHCPInfo? dhcpInfo, bool configuring = false, String? configResult, int? errorCode})

Properties

configResult String?
配网成功信息
getter/setter pair
configuring bool
获取到WIFI配置之后,发起WIFI配网
final
dhcpInfo DHCPInfo?
getter/setter pair
errorCode int?
错误值
getter/setter pair
gettingWifiInfo bool
正在获取WIFI配置信息 ssid scanResult dhcpInfo
final
hashCode int
The hash code for this object.
no setteroverride
isSuccess bool
配网是否成功
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanResult WifiScanResult?
getter/setter pair
ssid String?
getter/setter pair

Methods

copyWith({bool? gettingWifiInfo, String? ssid, WifiScanResult? scanResult, DHCPInfo? dhcpInfo, bool? configuring, String? configResult, int? errorCode}) WifiConfigState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override