NativeView class

AndroidView 缓存对象

Constructors

NativeView({required String viewType, int playHandle = -1})

Properties

hashCode int
The hash code for this object.
no setterinherited
playHandle int
当值 为 -1 时,代表可以使用 大于等于 0 时,代表正在使用
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewType String
对应 原生 PlatformView 名字
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited