MediaStatus enum

当前媒体播放的状态

Inheritance
Available extensions

Values

none → const MediaStatus

最初状态

created → const MediaStatus

起流成功,同步回调,判断是否创建成功,即返回大于等于0的playHandle. 同步的将状态修改为 buffering

buffering → const MediaStatus

正在加载状态,上层通过此状态,展示Loading.

playing → const MediaStatus

正在播放, 收到第一帧回调.只有在这个状态, onProgress()的回调才返回上层

paused → const MediaStatus

暂停状态, 只存在回放类型的播放器

stopping → const MediaStatus

在调用 stop 之前的状态. 因为 stop 接口 有时返回比较慢, 需要尽快的 从 playing 流转 到 一个 非 playing 的状态, 以致于 不再处理 play info 回调.

stopped → const MediaStatus

退出后台状态.之后回到前台,流转到 created . 这个状态可用于debug日志调试使用

disconnected → const MediaStatus

断开连接. 长时间退居后台时,可能触发此回调,再次到前台时,需要重新起流

completed → const MediaStatus

完成状态.一般存在云存回放中,播放完成,播放下一个

disposed → const MediaStatus

被销毁

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MediaStatus>
A constant List of the values in this enum, in order of their declaration.