MediaPlayerWidget class

Inheritance

Constructors

MediaPlayerWidget({Key? key, required MediaController controller, Orientation orientation = Orientation.portrait, Color backgroundColor = Colors.black, WidgetBuilder? emptyBuilder, bool fixSized = false, double padding = 0, double aspectRatio = 16.0 / 9.0, double? maxHeight})
const

Properties

aspectRatio double
画面比例
final
backgroundColor Color
背景颜色
final
controller MediaController
媒体播放控制器
final
emptyBuilder WidgetBuilder?
当视频资源为 null 时,展示的 空视图
final
fixSized bool
宽高是否固定比例
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxHeight double?
aspectRatio 小于 1时,需指定窗口的最大高度
final
orientation Orientation
屏幕旋转方向,横屏时将全屏展示
final
padding double
上下间距
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<MediaPlayerWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited