StartTalk class

开启设备对讲参数

Constructors

StartTalk({int? channel = 0, int? sampleRate = 8000, int? sampleBit = 16, String? encodeType = 'G711_ALAW'})

Properties

channel int?
getter/setter pair
encodeType String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleBit int?
getter/setter pair
sampleRate int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonString() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited