WifiConfig class

Annotations

Constructors

WifiConfig({String? ssid, String? wifiPwd, int? pwdType, DHCPInfo? dhcpInfo, int? timeOut = 20000})
const

Properties

dhcpInfo DHCPInfo?
final
hashCode int
The hash code for this object.
no setterinherited
pwdType int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ssid String?
final
timeOut int?
final
wifiPwd String?
final

Methods

copyWith({String? ssid, String? wifiPwd, int? pwdType, DHCPInfo? dhcpInfo, int? timeOut}) WifiConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited