CreateMessage class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mediaType ↔ int
-
媒体类型
getter/setter pair
- message ↔ String
-
json 参数
getter/setter pair
- playHandle ↔ int
-
播放句柄
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textureId ↔ int
-
Android纹理ID
getter/setter pair
- viewType ↔ String
-
渲染的原生 viewType
getter/setter pair
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object result) → CreateMessage