WifiAPI class

Constructors

WifiAPI({BinaryMessenger? binaryMessenger})
Constructor for WifiAPI. The binaryMessenger named argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkWifiState() Future<int>
检查Wifi状态
closeWifi() Future<void>
关闭WIFI
getBSSID() Future<String>
getDHCPInfo() Future<DHCPInfo>
getSSID() Future<String>
getWifiScanResult() Future<WifiScanResult>
isWifiEnable() Future<bool>
WIFI 是否可用
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openWifi() Future<bool>
打开wifi
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

codec → const MessageCodec<Object?>