JFImage class

Inheritance

Constructors

JFImage.croppingDiagramSDCard({Key? key, required String szDevId, required String assetName, required String localPath, required AddDownloadComPicToTaskList? croppingDiagramParam, BoxFit fit = BoxFit.contain, double? width, double? height})
JFImage.originalPicSDCard({Key? key, required String szDevId, required int? channel, required String assetName, required String? fileName, required String localPath, required DateTime? beginTime, required DateTime? endTime, DownloadFunction? downloadStatus, BoxFit fit = BoxFit.contain, double? width, double? height})
JFImage.thumbnailSDCard({Key? key, required String szDevId, required String assetName, required String localPath, required DateTime? beginTime, required DateTime? endTime, BoxFit fit = BoxFit.contain, double? width, double? height})

Properties

assetName String
默认图片(本地图片)
getter/setter pair
beginTime DateTime?
录像段文件缩略图下载开始时间
getter/setter pair
channel int?
通道号
getter/setter pair
croppingDiagramParam AddDownloadComPicToTaskList?
下载裁切图Json对象
getter/setter pair
downloadStatus DownloadFunction?
下载进度
getter/setter pair
endTime DateTime?
录像段文件缩略图下载结束时间
getter/setter pair
fileName String?
文件名
getter/setter pair
fit BoxFit
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height double?
getter/setter pair
imageType ImageType
getter/setter pair
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
localPath String
图片保存地址
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
szDevId String
getter/setter pair
width double?
getter/setter pair

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<JFImage>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited