JFImageProvider class

Inheritance

Constructors

JFImageProvider({required String localPath, required ImageType imageType, required String szDevId, AddDownloadComPicToTaskList? param, RecordDownloadModel? fileDownloadModel, DateTime? beginTime, DateTime? endTime, DownloadFunction? downloadStatus})

Properties

beginTime DateTime?
录像段文件缩略图下载开始时间
getter/setter pair
downloadStatus DownloadFunction?
下载进度
getter/setter pair
endTime DateTime?
录像段文件缩略图下载结束时间
getter/setter pair
fileDownloadModel RecordDownloadModel?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
imageType ImageType
getter/setter pair
localPath String
final
param AddDownloadComPicToTaskList?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
szDevId String
getter/setter pair

Methods

createStream(ImageConfiguration configuration) ImageStream
Called by resolve to create the ImageStream it returns.
inherited
evict({ImageCache? cache, ImageConfiguration configuration = ImageConfiguration.empty}) Future<bool>
Evicts an entry from the image cache.
inherited
loadBuffer(JFImageProvider key, DecoderBufferCallback decode) ImageStreamCompleter
Converts a key into an ImageStreamCompleter, and begins fetching the image.
inherited
loadImage(JFImageProvider key, ImageDecoderCallback decode) ImageStreamCompleter
Converts a key into an ImageStreamCompleter, and begins fetching the image.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
obtainCacheStatus({required ImageConfiguration configuration, ImageErrorListener? handleError}) Future<ImageCacheStatus?>
Returns the cache location for the key that this ImageProvider creates.
inherited
obtainKey(ImageConfiguration configuration) Future<JFImageProvider>
Converts an ImageProvider's settings plus an ImageConfiguration to a key that describes the precise image to load.
override
resolve(ImageConfiguration configuration) ImageStream
Resolves this image provider using the given configuration, returning an ImageStream.
inherited
resolveStreamForKey(ImageConfiguration configuration, ImageStream stream, JFImageProvider key, ImageErrorListener handleError) → void
Called by resolve with the key returned by obtainKey.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited