WifiPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • WifiPlatform
Implementers

Constructors

WifiPlatform()
Constructs a VideoPlayerPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDHCPInfo() Future<DHCPInfo>
getSSID() Future<String>
getWifiScanResult() Future<WifiScanResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance WifiPlatform
The instance of WifiPlatform to use.
getter/setter pair