DeviceUpgradeProgressResponse class
Constructors
- DeviceUpgradeProgressResponse({required UpgradeState state, required int progress, required int error})
Properties
- error ↔ int
-
步骤结果,< 0表示失败
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- progress ↔ int
-
设备升级进度
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ UpgradeState
-
设备升级类型
设备升级步骤
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited