MediaDownloadAPI class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
xcCancelDownload({required int handle})
→ void
-
取消下载
handle 开始下载时返回的下载句柄
回调码 5003
-
xcCancelDownloadCloudRecord(int handle)
→ Future<bool>
-
取消云存录像下载
handle 开始下载时返回的下载句柄
回调码 5003
return code:0 , str:function data:json数据
-
xcDevAddDownloadComPicToTaskList(String deviceId, String szFileName, AddDownloadComPicToTaskList param)
→ Future<List<int>>
-
-
xcDevCancelDownloadComPic(String deviceId)
→ Future<int>
-
-
xcDevCancelDownloadRecordThumbnail()
→ Future<int>
-
-
xcDevDownloadRecordThumbnail(String deviceId, DownloadRecordThumbnailModel param)
→ Future<List<int>>
-
-
xcDownloadCardRecordFile(String deviceId, String params)
→ Future<int>
-
卡回放文件下载 返回下载句柄
-
xcDownloadCloudRecord(String url, String urlExInfo, String fileName)
→ Future<Map<String, dynamic>>
-
云存录像下载
url视频url
urlExInfoUrl拓展参数(例如平台infoEx中的信息)
fileName要保存的文件名称---支持保存为MP4、h264,通过文件后缀保存文件格式
return code:0 , str:function data:json数据
回调码 30013
param1为1----正在下载---param2对应下载进度
param1为2---转换文件进度(MP4文件)—param2对应转换进度
param1为10---下载完成---param2大于等于0表示下载成功,param2小于0表示下载失败
-
xcDownloadCloudRecordFile(String url, String urlExInfo, String fileName)
→ Future<int>
-
-
xcDownloadRecordByFile(String deviceId, RecordDownloadModel model)
→ Future<bool>
-
录像下载-by文件名
deviceId序列号
szParam设置的Json数据
return code:0 , str:function data:json数据
回调码 12006
-
xcDownloadRecordOriginalPic(String deviceId, RecordDownloadModel model)
→ Future<List<int>>
-