XCloudAlarmMessageApiHost class abstract
XCloudAlarmMessageApiHost 报警消息相关 ####################################################################
- Annotations
-
- @HostApi.new()
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
alarmInit(
String szInitInfo, int seq) → OriginResponse -
报警功能初始化 zh_CN
szInitInfo初始化jsonseq自定义值 return code:0 -
alarmQuerySubscribeStatus(
String szReqJson, int seq) → OriginResponse -
查询报警消息订阅状态
messagejson 参数 return code:0 data:json数据 -
deleteAlarmMessages(
String szReqJson, int seq) → OriginResponse -
批量删除报警消息
szReqJsonjson 参数seq自定义值 return code:0 data:json数据 -
getPhoneToken(
) → OriginResponse - 获取手机推送的token,tokenType bundleId return code:0 data:自己封装的json数据 {'token':'','tokenType':'','bundleId'}
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryAlarmMsgList(
String szReqJson, int seq) → OriginResponse -
报警消息列表查询
szReqJsonjson 参数seq自定义值 return code:0 data:json数据 -
subscribeDeviceAlarmMessages(
String message, int seq) → OriginResponse -
报警消息订阅
messagejson 参数seq自定义值 return code:0 -
toString(
) → String -
A string representation of this object.
inherited
-
unsubscribeDevicesAlarmMessages(
String szReqJson, int seq) → OriginResponse -
取消报警消息订阅
messagejson 参数seq自定义值 return code:0 -
xcAlarmCalendar(
String deviceID, String jsParam, int seq) → OriginResponse -
报警日历查询
jsParam请求参数---JSON格式 seq 自定义值
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited