XCloudDeviceApiHost class abstract
XCloudDeviceApiHost 设备相关 ####################################################################
- Annotations
-
- @HostApi.new()
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteDevsInfo(
String deviceIDs) → void -
从SDK本地缓存中清除设备信息
szDevIds设备序列号,支持批量,多个序列号用';'隔开 -
devGetChnConfig(
String deviceID, int channelNo, String commandName, int command, int timeout, int seq) → OriginResponse -
获取设备通道配置
deviceID序列号channelNo通达号commandName配置命令字command消息ID 通用配置1042timeout超时时间seq索引,自定义值 return code:0 , str:function data:json数据 -
devGetCurNetType(
String deviceID) → OriginResponse - @brief 获取当前设备网络类型(同步接口) @param szDevId 设备序列号或IP+Port @return >=0:对应不同类型;<0:未登录状态。对应EDEV_CNN_TYPE
-
devGetLocalPassword(
String deviceID) → OriginResponse -
获取本地缓存设备登录密码
deviceID序列号 -
devGetLocalUserName(
String deviceID) → OriginResponse -
获取本地缓存设备登录名
deviceID序列号 -
devGetSysConfig(
String deviceID, String commandName, int command, int timeout, int seq) → OriginResponse -
获取设备系统配置
deviceID序列号channelNo通达号commandName配置命令字command消息ID 通用配置1042timeout超时时间seq索引,自定义值 return code:0 , str:function data:json数据 -
deviceLogin(
String deviceID, int seq) → OriginResponse -
登陆设备
deviceID设备序列号 or ip+portuserName用户名pwd密码seq自定义值 return code:0 -
devSetChnConfig(
String deviceID, int channelNo, String commandName, String config, int configLen, int command, int timeout, int seq) → OriginResponse -
设置设备通道配置
deviceID序列号channelNo通达号commandName配置命令字config设置的Json数据configLen设置的Json数据长度command消息ID 通用配置1040timeout超时时间seq索引,自定义值 return code:0 , str:function data:json数据 -
devSetSysConfig(
String deviceID, String commandName, String config, int configLen, int command, int timeout, int seq) → OriginResponse -
设置设备系统配置
deviceID序列号commandName配置命令字config设置的Json数据configLen设置的Json数据长度command消息ID 通用配置1040timeout超时时间seq索引,自定义值 return code:0 , str:function data:json数据 -
findCloudRecordAxis(
String param, int seq) → OriginResponse -
查询云回放时间轴
paramjson参数seq可选 return str json数据 -
findCloudRecordFile(
String param, int seq) → OriginResponse -
查询云回放文件
paramjson参数seq可选 return str json数据 -
findRecordFile(
String deviceID, String param, int seq) → OriginResponse -
查询一个时间段内 录像文件
录像文件名,和时间轴联动,展示缩略图deviceID设备序列号 or ip+portparamjson参数seq自定义值 return code:0 str:jsonName data:json数据 -
finRecordByTime(
String deviceID, String param, int seq) → OriginResponse -
查询一个时间段内每一分钟 录像
是否有录像,录像类型,用于绘制时间轴deviceID设备序列号 or ip+portparamjson参数seq自定义值 return code:0 byteData:1,1,10,0,0,0 -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
ptzControl(
String deviceID, int channelIndex, String command, int stop, int speed, int seq) → OriginResponse -
云台控制
deviceID设备序列号 or ip+portchannelIndex通道号command云台控制命令stop0:开始运动 1:停止运动speed移动速度seq自定义值 return code:0 (无需等待回调,直接返回接口调用结果即可) -
searchDevices(
int timeout, int seq) → OriginResponse -
局域网搜索设备
timeout超时时间seq自定义值 return 结构体,解析之后包装成 json字符串 回调码 13001 -
setLocalUserNameAndPwd(
String deviceID, String userName, String pwd, int seq) → OriginResponse -
把设备登录名和设备登录密码缓存到本地
deviceID设备序列号 or ip+portuserName用户名pwd密码seq自定义值 return code:0 (无需等待回调,直接返回接口调用结果即可) -
startWifiConfig(
String ssid, String wifiPwd, int pwdType, int ipAddress, int netMask, int gateway, int dns1, int dns2, int timeOut, int seq) → OriginResponse -
开始WIFI配网
ssidssidwifiPwdWIFI密码pwdType原生返回ipAddressipnetMask网关dns1dns1dns2dns2timeOut超时时间seq自定义值 return code:0 data:sn序列号 -
stopDistribute(
int seq) → void - 停止WIFI配网 无需返回值
-
toString(
) → String -
A string representation of this object.
inherited
- 将设备信息缓存到SDK(分享设备)
-
xcDevDeleteDevPtzTour(
String deviceID, int channel, int tourIndex) → OriginResponse - 删除预置点
-
xcDeviceChannelConfigNotLogin(
String deviceID, int channel, String commandName, String configJs, int configJsLength, int cmdReq, int timeout, int seq) → OriginResponse - 设备通道配置操作(不登录) deviceID 设备序列号或IP+Port channel 通道 commandName 配置命令字 configJs 设置的Json数据 configJsLength 设置的Json数据长度 cmdReq 消息值 timeout 超时时间 seq 自定义值
-
xcDeviceIsSearched(
String deviceID) → OriginResponse - 同步接口,判断设备是否在局域网搜索过,搜索过的话 预览高清
-
xcDeviceResetPwd(
String deviceId, String pOldPwd, String pNewPwd, String loginUserName, int seq) → OriginResponse -
重设设备登录密码
deviceId设备序列号或IP+PortpOldPwd旧密码pNewPwd新密码loginUserName设备登录用户名 seq 自定义值 -
xcDeviceSDCalendar(
String deviceID, String jsParam, int timeout, int seq) → OriginResponse -
查询设备端录像日历(SD卡)
deviceID设备序列号或IP+PortjsParam请求参数---JSON格式timeout超时时间 seq 自定义值 -
xcDeviceSleep(
String deviceId) → void - 设备休眠. 没有回调,默认成功, 业务上过 6s 重新获取状态
-
xcDeviceSystemConfigNotLogin(
String deviceID, String commandName, String configJs, int configJsLength, int cmdReq, int timeout, int seq) → OriginResponse - 设备系统配置操作(不登录) deviceID 设备序列号或IP+Port commandName 配置命令字 configJs 设置的Json数据 configJsLength 设置的Json数据长度 nCmdReq 消息值 nTimeout 超时时间 nSeq 自定义值
-
xcDeviceWakeup(
String deviceId, int timeout, int seq) → OriginResponse -
设备唤醒
deviceId设备序列号timeout超时时间seqseq -
xcDevPtzPreset(
String deviceID, int channel, String szPTZCommand, int preset, int seq) → OriginResponse -
设置预置点
deviceID设备序列号 or ip+portchannel通道号szPTZCommand控制命令preset预置点id, index作为 idseq自定义值 -
xcDevPtzTour(
String deviceID, int channel, int tourIndex, bool start, int times) → OriginResponse - 开始巡航
-
xcDevSetPtzTourPoint(
String deviceID, int channel, int presetPoint, int step, int tourIndex, bool add) → OriginResponse - 设置巡航点
-
xcGetDeviceInfo(
String deviceID, String type, int seq) → OriginResponse -
查询设备信息
deviceID设备序列号或IP+Porttype目前支持 SystemInfo 、 SystemFunction seq 自定义值 -
xcGetDeviceState(
String deviceId, int stateType) → OriginResponse -
单个获取设备在线状态(同步接口), 比如低功耗设备
deviceId设备序列号stateType状态类型(上层定义) eg. EFunDevStateType_IDR = 8, //门铃状态 -
xcGetDeviceToken(
String deviceID, int seq) → OriginResponse -
获取设备token
deviceID设备序列号或IP+Port seq 自定义值 -
xcLoginOut(
String deviceID, int seq) → OriginResponse -
设置设备登出
deviceID设备序列号或IP+Port seq 自定义值 -
xcParseRandomUserInfo(
String deviceID, String encodeDataStr, int seq) → OriginResponse -
解析设备随机用户信息
deviceID设备序列号或IP+PortencodeDataStr被加密的数据 seq 自定义值 return 解析成功后会返回到OriginResponse对象中的data属性 -
xcSetDeviceToken(
String deviceID, String token, int seq) → OriginResponse -
设置设备token
deviceID设备序列号或IP+Porttoken设备token seq 自定义值 -
xcStartSendFileToDevice(
String deviceID, String paramJsStr, String filePath, int timeout, int seq) → OriginResponse -
发送文件到设备端
回调码 13010
deviceID设备序列号paramJsStr请求的Json内容filePath文件路径timeout超时时间 -
xcStopSendFileToDevice(
int handle, int seq) → OriginResponse -
关闭发送文件到设备端
handle由xcStartSendFileToDevice这个接口返回的操作句柄
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited