XCloudDeviceUpgradeAPIHost class abstract
设备升级相关 ####################################################################
- Annotations
-
- @HostApi.new()
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
xcDeviceDownloadFile(
String commandBody, String fileSavePath, int seq) → OriginResponse - 下载固件到App本地
-
xcDeviceUpgradeByFile(
String deviceID, String filePath, int seq) → OriginResponse -
设备升级-byfile
deviceID设备序列号filePath给设备升级的固件文件地址 回调码 1306 -
xcDeviceUpgradeBySelf(
String deviceId, String commandBody, int seq) → OriginResponse -
xcDeviceVersionCheck(
String deviceId, String commandBody, int seq) → OriginResponse -
检查设备是否需要升级,支持多模块检测
deviceId设备序列号 commandId 13400
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited