XCloudVideoDownloadApiHost class abstract
- Annotations
-
- @HostApi.new()
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
int handle) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
xcCancelDownload(
int handle, int seq) → void -
取消下载
handle开始下载时返回的下载句柄seq索引,自定义值 -
xcDownloadComplete(
int handle) → void - 下载完成,原生将任务移除,释放资源
-
xcDownloadFile(
String deviceId, int videoType, String param, int handle, int seq) → OriginResponse -
统一视频下载
///
deviceID序列号videoType0 卡 1 云param参数 返回下载句柄
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited