BleDistributeController class
蓝牙搜索设备
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSearching ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeOut ↔ int
-
单次扫描超时时间
getter/setter pair
Methods
-
addSearchListener(
OnBleSearched searched) → void -
baseConfig(
{int timeout = 25000}) → dynamic - 基础设置
-
connectDevice(
String productId, String mac) → Future< bool> - 链接设备
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startsSearchDevices(
{int timeout = 25000}) → Future< bool> -
开启搜索设备
timeout超时时间 -
stopSearchDevices(
) → dynamic - 停止蓝牙搜索
-
toString(
) → String -
A string representation of this object.
inherited
-
writeDataToDevice<
T> (String ssid, String pwd, String mac) → Future< T> - 将wifi信息写入设备
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → BleDistributeController
-
final