AudioPlayerHost class
音频对讲
Constructors
- AudioPlayerHost({BinaryMessenger? binaryMessenger})
-
Constructor for AudioPlayerHost. The
binaryMessengernamed argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendTalkData(
int arg_audioHandle) → Future< int> - 发送音频数据,数据由原生SDK发送,只需告诉原生可以发送数据即可
-
setVolume(
int arg_audioHandle, int arg_volume) → Future< int> -
startTalk(
String arg_deviceId, String arg_param, int arg_type) → Future< TalkMessage> - 开启对讲
-
stopTalkPlay(
int arg_audioHandle, int arg_type) → Future< int> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
codec
→ const MessageCodec<
Object?>