instance property
WifiPlatform
get
instance
The instance of WifiPlatform to use.
Defaults to a placeholder that does not override any methods, and thus
throws UnimplementedError in most cases.
Implementation
static WifiPlatform get instance => _instance;
set
instance
(WifiPlatform instance)
Platform-specific plugins should override this with their own platform-specific class that extends WifiPlatform when they register themselves.
Implementation
static set instance(WifiPlatform instance) {
PlatformInterface.verify(instance, _token);
_instance = instance;
}